@@ -30,7 +30,7 @@ class Builder(_BaseRepositoryObject):
         @param repo: repository name
         @param config: common Config object
         """
-        super(Builder, self).__init__(repo=repo, create=False)
+        super().__init__(repo=repo, create=False)
         self.config = config
         self.count = 0
         self.stats = defaultdict(int)
@@ -45,7 +45,7 @@ class Builder(_BaseRepositoryObject):
         if not isinstance(other, Builder):
             return False
         else:
-            return all((super(Builder, self).__eq__(other),
+            return all((super().__eq__(other),
                         self.config.environments == other.config.environments))
 
     def __ne__(self, other):
@@ -66,12 +66,14 @@ class Builder(_BaseRepositoryObject):
                 # Check out build request's changeset
                 logging.info("found build request: {0} in {1}".format(request, request.repo))
                 self.count += 1
-                with self.repo.checkout(tempfile.mkdtemp(), rev=request.changeset.rev) as work:
+                temp = tempfile.mkdtemp()
+                logging.debug("directory for checkout: {0}".format(temp))
+                with self.repo.checkout(temp, rev=request.changeset.rev) as work:
 
                     # Update the configuration from the changeset
                     work.chdir()
                     path = common.find_config(work.path, walk=True)
-                    if path:  # pragma: no cover - the test repo does not have a config
+                    if path:
                         logging.info("updating the build configuration from the changeset...")
                         self.config.update(path)
 
@@ -164,7 +166,7 @@ class Builder(_BaseRepositoryObject):
         if command:
             if path:
                 command = "cd {p} && {c}".format(p=path, c=command)
-            if self.config.virtualenv:  # pragma: no cover - OS determines coverage
+            if self.config.virtualenv:
                 if os.name == 'nt':
                     command = "{v}\\Scripts\\activate && {c}".format(v=VIRTUALENV, c=command)
                 else:
@@ -189,7 +191,7 @@ def run(config, daemon=False, test=False):
 
     while True:
         for builder in builders:
-            if isinstance(test, basestring):
+            if isinstance(test, str):
                 logging.info("testing [{s}] of {b}...".format(b=builder, s=test))
                 builder.test(single=test)
             elif test:
@@ -206,19 +208,26 @@ def run(config, daemon=False, test=False):
 
 
 # TODO: share the common logic with tracking, builder, and poller
-def main():  # pragma: no cover - tested manually
+def main():  # pragma: no cove, tested by integration tests
     """Process command-line arguments and run the program.
     """
     # Main parser
-    parser = argparse.ArgumentParser(prog=BUILDER, description=__doc__, formatter_class=common.formatter_class)
+    parser = argparse.ArgumentParser(prog=BUILDER, description=__doc__,
+                                     formatter_class=common.formatter_class)
     parser.add_argument('-V', '--version', action='version', version=VERSION)
-    parser.add_argument('-v', '--verbose', action='count', help="enable verbose logging")
-    parser.add_argument('-d', '--daemon', action='store_true', help="keep the process running")
-    parser.add_argument('-t', '--test', metavar='ALIAS', nargs='?', const=True, help="dry run locally as a test")
+    parser.add_argument('-v', '--verbose', action='count', default=0,
+                        help="enable verbose logging")
+    parser.add_argument('-d', '--daemon', action='store_true',
+                        help="keep the process running")
+    parser.add_argument('-t', '--test', metavar='ALIAS', nargs='?', const=True,
+                        help="dry run locally as a test")
     parser.add_argument('repo', nargs='*', help="repository names")
-    parser.add_argument('--config', metavar='PATH', help="path to a configuration file")
-    parser.add_argument('--no-config', action='store_true', help="ignore local configuration files")
-    parser.add_argument('--env', metavar='ALIAS', help="environment alias for this machine")
+    parser.add_argument('--config', metavar='PATH',
+                        help="path to a configuration file")
+    parser.add_argument('--no-config', action='store_true',
+                        help="ignore local configuration files")
+    parser.add_argument('--env', metavar='ALIAS',
+                        help="environment alias for this machine")
 
     # Parse arguments
     args = parser.parse_args()
@@ -247,5 +256,5 @@ def main():  # pragma: no cover - tested manually
         sys.exit(1)
 
 
-if __name__ == '__main__':  # pragma: no cover - tested manually
+if __name__ == '__main__':  # pragma: no cover, tested by integration tests
     main()
