@@ -17,17 +17,21 @@ import logging
 from veracity import common
 from veracity import settings
 
-try:  # pragma: no cover - OS determines path coverage
+try:  # pragma: no cover, installation
     if os.name == 'nt':
         import pbs  # pylint: disable=F0401,W0611
-        from pbs import ErrorReturnCode  # pylint: disable=F0401,W0611
+        ErrorReturnCode = pbs.ErrorReturnCode
         if not os.path.isfile(settings.VSCRIPT_PATH_WINDOWS):
             raise ImportError
         vscript = pbs.Command(settings.VSCRIPT_PATH_WINDOWS)  # pylint: disable=C0103
     else:
         from sh import ErrorReturnCode  # pylint: disable=F0401,W0611
-        from sh import vscript  # pylint: disable=F0401,E0611
-except ImportError:  # pragma: no cover - only occurs with missing dependency
+        if os.getenv('VSCRIPT_PATH'):
+            import sh
+            vscript = sh.Command(os.getenv('VSCRIPT_PATH'))  # pylint: disable=C0103
+        else:
+            from sh import vscript  # pylint: disable=F0401,E0611
+except ImportError:  # pragma: no cover, installation
     raise EnvironmentError("vscript is not installed")
 
 
@@ -62,10 +66,12 @@ def report_build(repo, *args):
     except VeracityScriptException as exception:
         msg = str(exception).rsplit(':', 1)[-1].strip()
         logging.debug("{0} error: {1}".format(REPORT_BUILD_JS, msg))
-        if "is not a valid" in msg:  # pragma: no cover, TODO: try to get coverage
-            raise ValueError("invalid arguments to report build: {0}".format(' '.join(args)))
+        if "is not a valid" in msg:
+            err = "invalid report build arguments: {0}".format(' '.join(args))
+            raise ValueError(err)
         elif "statusRec is null" in msg:
-            raise VeracityScriptException("no build configuration for: {0}".format(repo))
+            err = "no build configuration for: {0}".format(repo)
+            raise VeracityScriptException(err)
         elif "is null" in msg:
             logging.warning("no build defined for the current environment")
         else:
@@ -76,18 +82,24 @@ def run(*args, **kwargs):
     """Run a Veracity script with the given arguments.
     @raise VeracityScriptException: when Veracity scripting returns an error
     """
+    sargs = ' '.join((str(a) for a in args))
+    skwargs = ' '.join(('{}={}'.format(str(k), str(v))
+                        for k, v in kwargs.items()))
+    logging.debug("$ vscript {} {}".format(sargs, skwargs))
     command = vscript.bake(*args, **kwargs)
-    logging.debug('$ ' + str(command))
     try:
         result = command()
     except ErrorReturnCode as erc:
+        out = (erc.stdout or erc.stderr).decode('utf-8').strip()
         msg = ("\n\nIN: {0}"
                "\n\nRAN: {1}"
-               "\n\nOUTPUT:{2}\n").format(os.getcwd(), erc.full_cmd,
-                                          (erc.stdout or erc.stderr).strip())
+               "\n\nOUTPUT:{2}\n").format(os.getcwd(), erc.full_cmd, out)
         raise VeracityScriptException(msg)
     else:
-        return result.stdout.strip()
+        if os.name == 'nt':
+            return result.stdout.strip()
+        else:
+            return result.stdout.decode('utf-8').strip()
 
 
 def parse(output, style=None):
@@ -118,7 +130,7 @@ def parse(output, style=None):
         raise ValueError("unknown style: {0}".format(style))
 
 
-if __name__ == '__main__':  # pragma: no cover - this is tested manually
+if __name__ == '__main__':  # pragma: no cover, integration
     common.configure_logging()
     for name in sys.argv[1:]:
-        print(init_builds(name))
+        print((init_builds(name)))
