@@ -5,22 +5,26 @@ Wrapper for Veracity's command-line interface.
 """
 
 import os
-from collections import defaultdict
 import logging
+from collections import defaultdict
 
 from veracity import settings
 
-try:  # pragma: no cover - OS determines path coverage
+try:  # pragma: no cover, installation
     if os.name == 'nt':
         import pbs  # pylint: disable=F0401,W0611
-        from pbs import ErrorReturnCode  # pylint: disable=F0401,W0611
+        ErrorReturnCode = pbs.ErrorReturnCode  # pylint: disable=C0103
         if not os.path.isfile(settings.VV_PATH_WINDOWS):
             raise ImportError
         vv = pbs.Command(settings.VV_PATH_WINDOWS)  # pylint: disable=C0103
     else:
         from sh import ErrorReturnCode  # pylint: disable=F0401,W0611
-        from sh import vv  # pylint: disable=F0401,E0611
-except ImportError:  # pragma: no cover - only occurs with missing dependency
+        if os.getenv('VV_PATH'):
+            import sh
+            vv = sh.Command(os.getenv('VV_PATH'))  # pylint: disable=C0103
+        else:
+            from sh import vv  # pylint: disable=F0401,E0611
+except ImportError:  # pragma: no cover, installation
     VERSION = ''
 else:
     VERSION = str(vv.version()).strip()
@@ -52,8 +56,11 @@ def run(*args, **kwargs):
     """Run a Veracity command with the given arguments.
     @raise VeracityException: when Veracity returns an error
     """
+    sargs = ' '.join((str(a) for a in args))
+    skwargs = ' '.join(('{}={}'.format(str(k), str(v))
+                        for k, v in kwargs.items()))
+    logging.debug("$ vv {} {}".format(sargs, skwargs))
     command = vv.bake(*args, **kwargs)
-    logging.debug('$ ' + str(command))
     try:
         result = command()
     except ErrorReturnCode as erc:
@@ -63,11 +70,12 @@ def run(*args, **kwargs):
                                           erc.full_cmd,
                                           erc.stderr.strip())
         raise VeracityException(msg)
-    except UnicodeDecodeError as ude:  # pragma: no cover - this occurs rarely
-        logging.warning(ude)
-        raise VeracityException("UnicodeDecodeError: {0}".format(ude))
     else:
-        return result.stdout.strip()
+        # pbs returns str not bytes
+        if os.name == 'nt':
+            return result.stdout.strip()
+        else:
+            return result.stdout.decode('utf-8').strip()
 
 
 def parse(output, style=None):  # pylint: disable=R0912
